<div class="fields-cut hideable">
  {% import 'includes/filters/filter-variables.j2' as vars %}

  <p class="doc">
    Remove columns from your dataset.
    {% with key='Cut-columns-filter' %}{% include "includes/help.html" %}{% endwith %}
  </p>

  {% set name='cut-include-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Whitelist: include only these tags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

  {% set name='cut-exclude-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Blacklist: include everything <i>but</i> these tags
      (comma-separated).
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

</div>
