<ul class="nav nav-tabs"> 
  <li class="{% if facet=='source' %}active{% endif %}">
    <a href="{{ data_url(recipe, 'source') }}">
      Source
    </a>
  </li>
  {% if recipe.args.url %}
  {% if using_tagger_p(recipe) or facet=='tagger' %}
  <li class="{% if facet=='tagger' %}active{% endif %}">
    <a href="{{ data_url(recipe, 'tagger') }}">
      Tags
    </a>
  </li>
  {% endif %}
  <li class="{% if facet=='edit' %}active{% endif %}">
    <a href="{{ data_url(recipe, 'edit') }}">
      Recipe
    </a>
  </li>
  <li class="{% if facet=='recipe' %}active{% endif %}">
    <a href="{{ data_url(recipe, 'recipe') }}">
      {% if recipe.recipe_id %}
      About
      {% else %}
      Save
      {% endif %}
    </a>
  </li>
  {% endif %}
  <li class="{% if facet=='view' %}active{% endif %}">
    <a href="{{ data_url(recipe) }}">
      View
    </a>
  </li>
</ul>
