<div class="panel panel-info">
  <div class="panel-body">
    <div id="{{ 'filter%02d' % n }}" class="field_filter form-group">
      <label for="{{ name }}">Filter type</label>
      {% set name='filter%02d' % n %}
      <select name="{{ name }}" class="form-control">
        <option value="">(none)</option>
        <option value="add"{% if recipe.args[name]=='add' %} selected="selected"{% endif %}>Add columns</option>
        <option value="append"{% if recipe.args[name]=='append' %} selected="selected"{% endif %}>Append datasets</option>
        <option value="clean"{% if recipe.args[name]=='clean' %} selected="selected"{% endif %}>Clean data</option>
        <option value="count"{% if recipe.args[name]=='count' %} selected="selected"{% endif %}>Count rows</option>
        <option value="cut"{% if recipe.args[name]=='cut' %} selected="selected"{% endif %}>Cut columns</option>
        <option value="dedup"{% if recipe.args[name]=='dedup' %} selected="selected"{% endif %}>Deduplicate rows</option>
        <option value="explode"{% if recipe.args[name]=='explode' %} selected="selected"{% endif %}>Explode data</option>
        <option value="merge"{% if recipe.args[name]=='merge' %} selected="selected"{% endif %}>Merge columns</option>
        <option value="rename"{% if recipe.args[name]=='rename' %} selected="selected"{% endif %}>Rename columns</option>
        <option value="replace"{% if recipe.args[name]=='replace' %} selected="selected"{% endif %}>Replace data</option>
        <option value="replace-map"{% if recipe.args[name]=='replace-map' %} selected="selected"{% endif %}>Replace data (mapping table)</option>
        <option value="select"{% if recipe.args[name]=='select' %} selected="selected"{% endif %}>Select rows</option>
        <option value="sort"{% if recipe.args[name]=='sort' %} selected="selected"{% endif %}>Sort rows</option>
      </select>
    </div>
  </div>
</div>
