<div class="fields-clean hideable">
  {% import 'includes/filters/filter-variables.j2' as vars %}

  <p class="doc">
    Clean up your dataset by standardising dates and numbers, removing
    whitespace, etc.
    {% with key='Clean-data-filter' %}{% include "includes/help.html" %}{% endwith %}
  </p>

  {% set name='clean-whitespace-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Normalise whitespace for these hashtags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

  {% set name='clean-toupper-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Convert to uppercase for these hashtags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

  {% set name='clean-tolower-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Convert to lowercase for these hashtags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

  {% set name='clean-date-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Standardise dates for these hashtags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

  {% set name='clean-num-tags%02d' % n %}
  <div id="{{ name }}" class="form-group">
    <label for="{{ name }}">
      Standardise numbers for these hashtags (comma-separated)
    </label>
    <input
        class="form-control"
        name="{{ name }}"
        value="{{ recipe.args[name] }}"
        pattern="^{{ vars.filters_pattern }}$"
        title="{{ vars.filters_help }}"
        placeholder="{{ vars.filters_placeholder }}"
        />
  </div>

</div>
